@@ -620,6 +620,11 @@ test_that("rtf19: Plot with page by on plot works as expected.", {
   
   dat <- mtcars[order(mtcars$cyl), ]
   
+  
+  fmt <- value(condition(x == 4, "4 Cylinder"),
+               condition(x == 6, "6 Cylinder"),
+               condition(x == 8, "8 Cylinder"))
+  
   p <- ggplot(dat, aes(x=disp, y=mpg)) + geom_point()
   
   
@@ -628,7 +633,7 @@ test_that("rtf19: Plot with page by on plot works as expected.", {
   
   plt <- create_plot(p, height = 4, width = 8) %>% 
     titles("Figure 1.0", "MTCARS Miles per Cylinder Plot", blank_row = "none") %>%
-    page_by(cyl, "Cylinders: ") %>% 
+    page_by(cyl, "Cylinders: ", format = fmt) %>% 
     footnotes("* Motor Trend, 1974") 
   
   rpt <- create_report(fp, output_type = "RTF") %>%
